@@ -5,7 +5,7 @@ use warnings;
 
 use Moose; # Catalyst::View;
 extends 'Catalyst::View::TT';
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use JSON;
 
 around 'render' => sub {
@@ -43,7 +43,7 @@ sub process {
 	}
 
 	if ($c->stash->{JSON}) {
-		my $body = $c->stash->{JSON};
+		my $body = $self->build_json($c, $c->stash->{JSON});
 		$body->{html} = $output;
 		$output = JSON->new->encode($body);
 		$c->response->content_type("application/json; charset=UTF-8");
@@ -59,6 +59,11 @@ sub process {
 	return 1;
 }
 
+sub build_json {
+	my ($self, $c, $json) = @_;
+	return ref $json ? $json : {};
+}
+
 1;
 
 __END__
@@ -69,7 +74,7 @@ Catalyst::View::TT::Progressive - Control the wrapper
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
